Stan Math Library: stan/math/prim/mat/fun/array_builder.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Classes | Namespaces
array_builder.hpp File Reference
`#include <stan/math/prim/mat/fun/promoter.hpp>`
`#include <vector>`

Go to the source code of this file.

## Classes
struct | stan::math::array_builder< T >
| Structure for building up arrays in an expression (rather than in statements) using an argumentchaining add() method and a getter method array() to return the result. More...

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

[ Stan Home Page ] © 2011–2016, Stan Development Team.